@@ -1,5 +1,5 @@
-import sys
 import asyncio
+import sys
 
 from loguru import logger
 
@@ -11,14 +11,17 @@ logger.remove(0)
 logger.add("wizwalker_debug.log", level="DEBUG", rotation="10 MB")
 
 
-async def main():
-    if sys.platform != "win32":
-        raise RuntimeError(f"This program is windows only, not {sys.platform}")
-
+async def run_console():
     walker = WizWalker()
     console = WizWalkerConsole(walker)
     await console.interact()
-    await walker.close()
+
+
+def main():
+    if sys.platform != "win32":
+        raise RuntimeError(f"This program is windows only, not {sys.platform}")
+
+    asyncio.run(run_console())
 
     # app = WizWalker()
     #
@@ -58,6 +61,7 @@ def wiz_command():
 
     # speed is the name :sunglasses:
     import time
+
     # this probably isn't enough time for some computers
     time.sleep(7)
 
@@ -67,9 +71,5 @@ def wiz_command():
     utils.wiz_login(newest_handle, username, password)
 
 
-def sync_main():
-    asyncio.run(main())
-
-
 if __name__ == "__main__":
-    sync_main()
+    main()
